@@ -10,7 +10,6 @@ from ..config.interface import ConfigInterface
 from ..core.exceptions import ExecutionException
 from ..core.settings import get_settings
 from ..engine import Engine
-from ..storage import Storage
 from ..execution.schedule import Schedule
 from ..experiment.experiment import Experiment
 from ..experiment.parser import parse_experiment
@@ -19,6 +18,8 @@ from ..index import Index
 from ..project import Project
 from ..project.export import Export
 from ..registration import Registration
+from ..storage import Storage
+from ..storage.models.filesystem import StorageFileSystemModel
 from ..utils.dicts import update_dict
 from ..utils.formatting import exception_to_str, msg
 from ..utils.host import get_host_info
@@ -27,6 +28,7 @@ from ..utils.identifiers import (
     encode_experiment_id,
     generate_experiment_id,
 )
+from ..utils.importing import resolve_instance
 from ..utils.traits import Jsonable
 
 
@@ -36,6 +38,9 @@ def to_color(experiment_id):
     )
 
 
+_latest = [None]
+
+
 class Execution(Jsonable):
     def __init__(
         self,
@@ -89,18 +94,41 @@ class Execution(Jsonable):
             self.project.default_component = self.function
             return self
 
+    @classmethod
+    def latest(cls):
+        return _latest[0]
+
+    @classmethod
+    def set_latest(cls, latest):
+        _latest[0] = latest
+
+    @classmethod
+    def create(self, args):
+        if isinstance(args, Execution):
+            return args
+
+        if args is None:
+            return Execution()
+
+        resolved = resolve_instance(args, Execution, "executions")
+        if resolved is not None:
+            return resolved
+
+        if isinstance(args, dict):
+            return Execution(**args)
+
+        if isinstance(args, (list, tuple)):
+            return Execution(*args)
+
+        raise ValueError(f"Invalid argument: {args}")
+
     def set_experiment(self, experiment):
         self.experiment = Experiment.create(experiment)
 
         # compute experiment directory
         experiment_directory = self.experiment.specification.get("directory", None)
         if experiment_directory is None:
-            experiment_directory = Registration.get().experiment_directory
-        if callable(experiment_directory):
-            experiment_directory = experiment_directory()
-            if experiment_directory is True:
-                # use default value
-                experiment_directory = "&PROJECT/&MODULE"
+            experiment_directory = get_settings()["default_directory"]
         if isinstance(experiment_directory, str):
             # replace magic variables
             project_name = self.project.name if self.project else ""
@@ -232,34 +260,50 @@ class Execution(Jsonable):
         return self
 
     def is_submitted(self):
-        # todo: use FileSystem abstraction
-        import fs
-
         try:
-            storage = fs.open_fs(
-                os.path.join(
-                    self.storage.config["url"], self.storage.config["directory"]
-                ),
-                create=False,
-            )
-            return storage.isdir(self.experiment_id)
-        except (
-            AttributeError,
-            KeyError,
-            TypeError,
-            ValueError,
-            fs.errors.ResourceNotFound,
-            fs.errors.CreateFailed,
-        ):
+            with open_fs(self.storage.config["url"]) as filesystem:
+                return filesystem.isdir(
+                    os.path.join(self.storage.config["directory"], self.experiment_id)
+                )
+        except (FileNotFoundError, AttributeError, KeyError, TypeError, ValueError):
             pass
         return False
 
     def submit(self):
+        if Registration.get().on_before_submit(self) is False:
+            return False
+
         self.storage.config["experiment"] = self.experiment_id
 
-        if not self.is_submitted():
+        # check if URL is an existing experiment
+        derived_from = None
+        try:
+            target = StorageFileSystemModel(self.storage.config["url"])
+            if target.is_valid():
+                # register URL as parent storage and rewrite to experiments/ subdirectory
+                self.storage.config["ancestor"] = {
+                    "url": self.storage.config["url"],
+                    "experiment": target.experiment_id,
+                }
+                self.storage.config["url"] = os.path.join(
+                    self.storage.config["url"], "experiments"
+                )
+                derived_from = self.storage.config["ancestor"]["url"]
+        except (ValueError, KeyError):
+            pass
+
+        is_submitted = self.is_submitted()
+        if not is_submitted:
             if len(self.schedule) == 0:
                 self.set_schedule()
+
+            def set_derived_from_flag(i, component, element):
+                element[1]["flags"]["DERIVED_FROM_STORAGE"] = derived_from
+                return element
+
+            self.schedule.transform(set_derived_from_flag)
+            storage = self.engine.storage_middleware(self.storage.config)
+
             now = pendulum.now()
             self.timestamp = now.timestamp()
             self.started_at = str(now)
@@ -270,44 +314,42 @@ class Execution(Jsonable):
             ):
                 code_backup = True
 
-            storage = self.engine.storage_middleware(self.storage.config)
-
-            url = os.path.join(
-                storage.get("url", "mem://"),
-                storage.get("directory", ""),
-                storage["experiment"],
-            )
-            with open_fs({"url": url, "create": True}) as filesystem:
+            # collect and write execution data
+            data = {
+                "url": os.path.join(
+                    storage.get("url", "mem://"),
+                    storage.get("directory", ""),
+                    storage["experiment"],
+                ),
+                "code.json": {
+                    "resolvers": {
+                        "experiment": getattr(
+                            self.experiment, "_resolved_by_expression", None
+                        ),
+                        "storage": None,
+                        "engine": getattr(self.engine, "_resolved_by_expression", None),
+                    },
+                    "code_backup": code_backup,
+                    "code_version": self.project.get_code_version(),
+                },
+                "code.diff": self.project.get_diff(),
+                "execution.json": self.serialize(),
+                "schedule.json": self.schedule.serialize(),
+                "host.json": get_host_info(),
+            }
 
+            with open_fs({"url": data["url"], "create": True}) as filesystem:
                 if code_backup:
                     self.project.backup_source_code(opener=filesystem.open)
 
-                code_version = self.project.get_code_version()
+                for k, v in data.items():
+                    if k.find(".") == -1:
+                        continue
+                    filesystem.save_file(name=k, data=v)
 
-                filesystem.save_file(
-                    "code.json",
-                    {
-                        "resolvers": {
-                            "experiment": getattr(
-                                self.experiment, "_resolved_by_expression", None
-                            ),
-                            "storage": None,
-                            "engine": getattr(
-                                self.engine, "_resolved_by_expression", None
-                            ),
-                        },
-                        "code_backup": code_backup,
-                        "code_version": code_version,
-                    },
-                )
-                filesystem.save_file("code.diff", self.project.get_diff())
+            self.index.add(data)
 
-                filesystem.save_file("execution.json", self.serialize())
-                filesystem.save_file("schedule.json", self.schedule.serialize())
-                filesystem.save_file("host.json", get_host_info())
-
-            # todo: pass the data directly as an StorageFileSystemModel
-            self.index.add(url)
+        Registration.get().on_submit(self, is_submitted)
 
         return self.engine.submit(self)
 
